import router from '../src/handler'
import { metricsSchema } from './schemas'
import fetch from 'cross-fetch'
import Ajv from 'ajv'

const ajv = new Ajv()

const headers = () => {
  const enc = Buffer.from(
    `${process.env.JIRA_USER}:${process.env.JIRA_PASS}`,
  ).toString('base64')
  return {Authorization:`Basic ${enc}`}
}

describe('handler', () => {

  beforeEach(() => {
    if (!globalThis.fetch) {
        globalThis.fetch = fetch;
    }    jest.resetModules()
  })

  test('Test Connection', async () => {
    const result = await router.handle(
      new Request(`http://localhost/jira-data-source/${process.env.JIRA_HOST}`, {
        method: 'GET',
        headers: headers()
      }),
    )
    expect(result.status).toEqual(200)
    const data = await result.json()
    expect(data.emailAddress).toEqual(process.env.JIRA_USER)
  })

  test('List Metrics', async () => {
    const result = await router.handle(
      new Request(`http://localhost/jira-data-source/${process.env.JIRA_HOST}/search`, {
        method: 'GET',
        headers: headers()
      }),
    )
    expect(result.status).toEqual(200)
    const metrics = await result.json()
    const valid = ajv.validate(metricsSchema,metrics)
    expect(valid).toBeTruthy();
  })

})
